pub struct Plan {
pub actions: Vec<PlannedAction>,
pub created_at: Instant,
pub explanation: Option<String>,
pub display_text: String,
}Expand description
A complete plan of actions to execute
Fields
actions: Vec<PlannedAction>All actions in the plan
created_at: InstantWhen this plan was created
explanation: Option<String>LLM’s explanation of what it plans to do
display_text: StringPre-formatted markdown text for display
Implementations
Sourceimpl Plan
impl Plan
Sourcepub fn new(actions: Vec<AgentAction>) -> Self
pub fn new(actions: Vec<AgentAction>) -> Self
Create a new plan from a list of actions
Sourcepub fn with_explanation(
explanation: Option<String>,
actions: Vec<AgentAction>,
) -> Self
pub fn with_explanation( explanation: Option<String>, actions: Vec<AgentAction>, ) -> Self
Create a new plan with an explanation from the LLM
Sourcepub fn update_action_status(
&mut self,
index: usize,
status: ActionStatus,
result: Option<ActionResult>,
error: Option<String>,
)
pub fn update_action_status( &mut self, index: usize, status: ActionStatus, result: Option<ActionResult>, error: Option<String>, )
Update an action’s status and regenerate display text
Sourcepub fn next_pending_action(&self) -> Option<(usize, &PlannedAction)>
pub fn next_pending_action(&self) -> Option<(usize, &PlannedAction)>
Get next pending action