pub fn load_from_paths(paths: &[PathBuf]) -> Option<LoadedInstructions>Expand description
Read and combine the instruction files at paths, truncating the
combined body to MAX_INSTRUCTIONS_BYTES if needed.
pub fn load_from_paths(paths: &[PathBuf]) -> Option<LoadedInstructions>Read and combine the instruction files at paths, truncating the
combined body to MAX_INSTRUCTIONS_BYTES if needed.