pub struct ToolCallId(pub u64);Expand description
Stable identifier for a single tool call inside a turn. The reducer
uses this to match ToolFinished results back to the slot in
TurnState::ExecutingTools::outcomes so results can land out of
order without ambiguity.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ToolCallId
impl Clone for ToolCallId
Sourcefn clone(&self) -> ToolCallId
fn clone(&self) -> ToolCallId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ToolCallId
Sourceimpl Debug for ToolCallId
impl Debug for ToolCallId
Sourceimpl<'de> Deserialize<'de> for ToolCallId
impl<'de> Deserialize<'de> for ToolCallId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ToolCallId
impl Display for ToolCallId
impl Eq for ToolCallId
Sourceimpl Hash for ToolCallId
impl Hash for ToolCallId
Sourceimpl Ord for ToolCallId
impl Ord for ToolCallId
Sourcefn cmp(&self, other: &ToolCallId) -> Ordering
fn cmp(&self, other: &ToolCallId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ToolCallId
impl PartialEq for ToolCallId
Sourcefn eq(&self, other: &ToolCallId) -> bool
fn eq(&self, other: &ToolCallId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ToolCallId
impl PartialOrd for ToolCallId
Sourceimpl Serialize for ToolCallId
impl Serialize for ToolCallId
impl StructuralPartialEq for ToolCallId