StepObserver

Trait StepObserver 

pub trait StepObserver {
    // Required method
    fn observe(&mut self, obs: Observation<'_>);
}
A hook on every message an Engine pumps.

Synchronous and non-blocking: observers that emit events or progress to channels (such as the subagent progress relay or broadcast streams) use non-blocking channels to ensure observer dispatch never blocks or adds latency to the reduction pump.

Required Methods

fn observe(&mut self, obs: Observation<'_>)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl StepObserver for ()

The no-op observer, for drivers that only want the reducer pumped.

Source

fn observe(&mut self, _obs: Observation<'_>)

Implementors