pub struct ModelFactory { /* private fields */ }Expand description
Model factory - creates model instances
Implementations
Sourceimpl ModelFactory
impl ModelFactory
Sourcepub fn new(config: BackendConfig) -> Self
pub fn new(config: BackendConfig) -> Self
Create a new model factory with explicit backend config
Sourcepub fn from_config(config: &Config) -> Self
pub fn from_config(config: &Config) -> Self
Create a factory from app::Config
Sourcepub async fn create_model(&self, model_id: &str) -> Result<Box<dyn Model>>
pub async fn create_model(&self, model_id: &str) -> Result<Box<dyn Model>>
Create a model from a full identifier (e.g., “ollama/llama3”)
Sourcepub async fn create(
model_id: &str,
config: Option<&Config>,
) -> Result<Box<dyn Model>>
pub async fn create( model_id: &str, config: Option<&Config>, ) -> Result<Box<dyn Model>>
Create a model instance from a model identifier with optional app config
Format examples:
- “ollama/qwen3-coder:30b” - Explicit Ollama provider
- “qwen3-coder:30b” - Defaults to Ollama
- “kimi-k2.5:cloud” - Ollama cloud model
Sourcepub async fn list_all_models() -> Result<Vec<String>>
pub async fn list_all_models() -> Result<Vec<String>>
List all models from all available providers
Returns a list of model identifiers in “provider/model” format. Only includes providers that are currently available.
Sourcepub async fn available_providers() -> Vec<String>
pub async fn available_providers() -> Vec<String>
Get list of available providers (static convenience)