pub fn render(state: &State, rstate: &mut RenderCache, frame: &mut Frame<'_>)Expand description
The entrypoint. Call once per render pass from the main loop.
pub fn render(state: &State, rstate: &mut RenderCache, frame: &mut Frame<'_>)The entrypoint. Call once per render pass from the main loop.