pub fn tasks_height(store: &ChecklistStore, collapsed: bool) -> u16Expand description
Height the layout should reserve for the checklist zone.
pub fn tasks_height(store: &ChecklistStore, collapsed: bool) -> u16Height the layout should reserve for the checklist zone.