pub struct PluginCapabilityPreview {
pub name: String,
pub declared_capabilities: Vec<String>,
pub capabilities_toml: Option<Value>,
pub hooks: Vec<String>,
pub mcp: Vec<String>,
pub bin: Vec<String>,
}Expand description
A summary of what a plugin declares it will do, shown before install/enable.
These are advisory disclosures for informed consent, not an enforced sandbox
(see PluginManifest::capabilities).
Fields
name: Stringdeclared_capabilities: Vec<String>capabilities_toml: Option<Value>hooks: Vec<String>mcp: Vec<String>bin: Vec<String>Trait Implementations
Sourceimpl Clone for PluginCapabilityPreview
impl Clone for PluginCapabilityPreview
Sourcefn clone(&self) -> PluginCapabilityPreview
fn clone(&self) -> PluginCapabilityPreview
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginCapabilityPreview
impl Debug for PluginCapabilityPreview
Sourceimpl<'de> Deserialize<'de> for PluginCapabilityPreview
impl<'de> Deserialize<'de> for PluginCapabilityPreview
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PluginCapabilityPreview, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PluginCapabilityPreview, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for PluginCapabilityPreview
impl Serialize for PluginCapabilityPreview
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more