pub struct RuntimeClient { /* private fields */ }Implementations
Sourceimpl RuntimeClient
impl RuntimeClient
pub fn auto() -> Self
pub fn daemon() -> Self
pub fn daemon_with_token(token: impl Into<String>) -> Self
pub fn local() -> Self
Sourcepub fn health(&self) -> Result<RuntimeRead<RuntimeHealth>>
pub fn health(&self) -> Result<RuntimeRead<RuntimeHealth>>
Errors
Errors if the daemon rejects the request or answers with an unexpected shape, and – when the call falls back to the local database – if that read fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn snapshot(&self) -> Result<RuntimeRead<RuntimeSnapshot>>
pub fn snapshot(&self) -> Result<RuntimeRead<RuntimeSnapshot>>
Errors
Errors if the daemon rejects the request or answers with an unexpected shape, and – when the call falls back to the local database – if that read fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn dashboard(&self) -> Result<RuntimeRead<RuntimeDashboard>>
pub fn dashboard(&self) -> Result<RuntimeRead<RuntimeDashboard>>
Errors
Errors if the daemon rejects the request or answers with an unexpected shape, and – when the call falls back to the local database – if that read fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn diagnostics(&self) -> Result<RuntimeRead<RuntimeDiagnostics>>
pub fn diagnostics(&self) -> Result<RuntimeRead<RuntimeDiagnostics>>
Errors
Errors if the daemon rejects the request or answers with an unexpected shape, and – when the call falls back to the local database – if that read fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn hygiene_preview(&self) -> Result<RuntimeRead<RuntimeHygienePreview>>
pub fn hygiene_preview(&self) -> Result<RuntimeRead<RuntimeHygienePreview>>
Errors
Errors if the daemon rejects the request or answers with an unexpected shape, and – when the call falls back to the local database – if that read fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn hygiene_archive(&self) -> Result<RuntimeRead<RuntimeHygieneArchive>>
pub fn hygiene_archive(&self) -> Result<RuntimeRead<RuntimeHygieneArchive>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn task_detail(&self, id: &str) -> Result<RuntimeRead<RuntimeTaskDetail>>
pub fn task_detail(&self, id: &str) -> Result<RuntimeRead<RuntimeTaskDetail>>
Errors
Errors if the daemon rejects the request or answers with an unexpected shape, and – when the call falls back to the local database – if that read fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn approval_detail(
&self,
id: &str,
) -> Result<RuntimeRead<RuntimeApprovalDetail>>
pub fn approval_detail( &self, id: &str, ) -> Result<RuntimeRead<RuntimeApprovalDetail>>
Errors
Errors if the daemon rejects the request or answers with an unexpected shape, and – when the call falls back to the local database – if that read fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn checkpoint_detail(
&self,
id: &str,
) -> Result<RuntimeRead<RuntimeCheckpointDetail>>
pub fn checkpoint_detail( &self, id: &str, ) -> Result<RuntimeRead<RuntimeCheckpointDetail>>
Errors
Errors if the daemon rejects the request or answers with an unexpected shape, and – when the call falls back to the local database – if that read fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn list_tasks(&self, limit: usize) -> Result<RuntimeRead<Vec<TaskRecord>>>
pub fn list_tasks(&self, limit: usize) -> Result<RuntimeRead<Vec<TaskRecord>>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn list_processes(
&self,
limit: usize,
) -> Result<RuntimeRead<Vec<ProcessRecord>>>
pub fn list_processes( &self, limit: usize, ) -> Result<RuntimeRead<Vec<ProcessRecord>>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn list_approvals(&self) -> Result<RuntimeRead<Vec<ApprovalRecord>>>
pub fn list_approvals(&self) -> Result<RuntimeRead<Vec<ApprovalRecord>>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn list_tool_runs(
&self,
limit: usize,
) -> Result<RuntimeRead<Vec<ToolRunRecord>>>
pub fn list_tool_runs( &self, limit: usize, ) -> Result<RuntimeRead<Vec<ToolRunRecord>>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn list_checkpoints(
&self,
limit: usize,
) -> Result<RuntimeRead<Vec<CheckpointRecord>>>
pub fn list_checkpoints( &self, limit: usize, ) -> Result<RuntimeRead<Vec<CheckpointRecord>>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn list_plugins(&self) -> Result<RuntimeRead<Vec<PluginInstallRecord>>>
pub fn list_plugins(&self) -> Result<RuntimeRead<Vec<PluginInstallRecord>>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn process_log(
&self,
id: &str,
tail_bytes: Option<u64>,
) -> Result<RuntimeProcessLog>
pub fn process_log( &self, id: &str, tail_bytes: Option<u64>, ) -> Result<RuntimeProcessLog>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn stop_process(&self, id: &str) -> Result<RuntimeOne<ProcessRecord>>
pub fn stop_process(&self, id: &str) -> Result<RuntimeOne<ProcessRecord>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn restart_process(&self, id: &str) -> Result<RuntimeOne<ProcessRecord>>
pub fn restart_process(&self, id: &str) -> Result<RuntimeOne<ProcessRecord>>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn open_process(&self, id: &str) -> Result<RuntimeProcessOpen>
pub fn open_process(&self, id: &str) -> Result<RuntimeProcessOpen>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn ports(&self) -> Result<RuntimePorts>
pub fn ports(&self) -> Result<RuntimePorts>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn approve(&self, id: &str) -> Result<RuntimeApprovalDecision>
pub fn approve(&self, id: &str) -> Result<RuntimeApprovalDecision>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn deny(&self, id: &str) -> Result<RuntimeApprovalDecision>
pub fn deny(&self, id: &str) -> Result<RuntimeApprovalDecision>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn restore_checkpoint(&self, id: &str) -> Result<RuntimeCheckpointRestore>
pub fn restore_checkpoint(&self, id: &str) -> Result<RuntimeCheckpointRestore>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn set_plugin_enabled(&self, id: &str, enabled: bool) -> Result<()>
pub fn set_plugin_enabled(&self, id: &str, enabled: bool) -> Result<()>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn model_info(&self, model: &str) -> Result<Value>
pub fn model_info(&self, model: &str) -> Result<Value>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.
Sourcepub fn set_safety_mode(&self, mode: &str) -> Result<Value>
pub fn set_safety_mode(&self, mode: &str) -> Result<Value>
Errors
Errors if the daemon rejects the action or answers with an unexpected shape, and – when the call falls back to acting on the local database – if that fails. A daemon that is simply not running is not an error: the client falls back.