pub struct RuntimeService { /* private fields */ }Implementations
Sourceimpl RuntimeService
impl RuntimeService
Sourcepub fn open_default() -> Result<Self>
pub fn open_default() -> Result<Self>
Errors
Errors if the runtime database cannot be opened, created, or migrated.
pub fn from_store(store: RuntimeStore) -> Self
Sourcepub fn health(&self) -> Result<RuntimeHealth>
pub fn health(&self) -> Result<RuntimeHealth>
Errors
Errors if a store query fails.
Sourcepub fn snapshot(&self) -> Result<RuntimeSnapshot>
pub fn snapshot(&self) -> Result<RuntimeSnapshot>
Errors
Errors if a store query fails.
Sourcepub fn dashboard(&self) -> Result<RuntimeDashboard>
pub fn dashboard(&self) -> Result<RuntimeDashboard>
Errors
Errors if a store query fails.
Sourcepub fn diagnostics(&self) -> Result<RuntimeDiagnostics>
pub fn diagnostics(&self) -> Result<RuntimeDiagnostics>
Errors
Errors if a store query fails.
Sourcepub fn hygiene_preview(&self) -> Result<RuntimeHygienePreview>
pub fn hygiene_preview(&self) -> Result<RuntimeHygienePreview>
Errors
Errors if a store query fails.
Sourcepub fn hygiene_archive(&self) -> Result<RuntimeHygieneArchive>
pub fn hygiene_archive(&self) -> Result<RuntimeHygieneArchive>
Errors
Errors if a store query fails.
Sourcepub fn task_detail(&self, id: &str) -> Result<RuntimeTaskDetail>
pub fn task_detail(&self, id: &str) -> Result<RuntimeTaskDetail>
Errors
Errors if no task has that id, or if a store query fails.
Sourcepub fn approval_detail(&self, id: &str) -> Result<RuntimeApprovalDetail>
pub fn approval_detail(&self, id: &str) -> Result<RuntimeApprovalDetail>
Errors
Errors if no approval has that id, or if a store query fails.
Sourcepub fn checkpoint_detail(&self, id: &str) -> Result<RuntimeCheckpointDetail>
pub fn checkpoint_detail(&self, id: &str) -> Result<RuntimeCheckpointDetail>
Errors
Errors if no checkpoint has that id, or if a store query fails.
Sourcepub fn list_tasks(&self, limit: usize) -> Result<Vec<TaskRecord>>
pub fn list_tasks(&self, limit: usize) -> Result<Vec<TaskRecord>>
Errors
Errors if a store query fails.
Sourcepub fn list_processes(&self, limit: usize) -> Result<Vec<ProcessRecord>>
pub fn list_processes(&self, limit: usize) -> Result<Vec<ProcessRecord>>
Errors
Errors if a store query fails.
Sourcepub fn list_approvals(&self) -> Result<Vec<ApprovalRecord>>
pub fn list_approvals(&self) -> Result<Vec<ApprovalRecord>>
Errors
Errors if a store query fails.
Sourcepub fn list_tool_runs(&self, limit: usize) -> Result<Vec<ToolRunRecord>>
pub fn list_tool_runs(&self, limit: usize) -> Result<Vec<ToolRunRecord>>
Errors
Errors if a store query fails.
Sourcepub fn list_checkpoints(&self, limit: usize) -> Result<Vec<CheckpointRecord>>
pub fn list_checkpoints(&self, limit: usize) -> Result<Vec<CheckpointRecord>>
Errors
Errors if a store query fails.
Sourcepub fn list_plugins(&self) -> Result<Vec<PluginInstallRecord>>
pub fn list_plugins(&self) -> Result<Vec<PluginInstallRecord>>
Errors
Errors if a store query fails.
Sourcepub fn process_log(
&self,
id: &str,
tail_bytes: Option<u64>,
) -> Result<RuntimeProcessLog>
pub fn process_log( &self, id: &str, tail_bytes: Option<u64>, ) -> Result<RuntimeProcessLog>
Errors
Errors if no record has that id, or if a store query fails.
Sourcepub fn stop_process(&self, id: &str) -> Result<ProcessRecord>
pub fn stop_process(&self, id: &str) -> Result<ProcessRecord>
Errors
Errors if no record has that id, or if a store query fails.
Sourcepub fn restart_process(&self, id: &str) -> Result<ProcessRecord>
pub fn restart_process(&self, id: &str) -> Result<ProcessRecord>
Errors
Errors if no record has that id, or if a store query fails.
Sourcepub fn open_process(&self, id: &str) -> Result<RuntimeProcessOpen>
pub fn open_process(&self, id: &str) -> Result<RuntimeProcessOpen>
Errors
Errors if no record has that id, or if a store query fails.
Sourcepub fn resolve_open_target(&self, target: &str) -> Result<String>
pub fn resolve_open_target(&self, target: &str) -> Result<String>
Errors
Errors if a store query fails.
Sourcepub fn ports(&self) -> Result<RuntimePorts>
pub fn ports(&self) -> Result<RuntimePorts>
Errors
Errors if a store query fails.
Sourcepub fn set_plugin_enabled(&self, id: &str, enabled: bool) -> Result<()>
pub fn set_plugin_enabled(&self, id: &str, enabled: bool) -> Result<()>
Errors
Errors if a store query fails.
Sourcepub fn set_safety_mode(&self, mode: &str) -> Result<SafetyConfig>
pub fn set_safety_mode(&self, mode: &str) -> Result<SafetyConfig>
Errors
Errors if a store query fails.
pub fn model_info(&self, model: &str) -> Value
Sourcepub fn approval_decision(
result: ApprovalReplayResult,
) -> Result<RuntimeApprovalDecision>
pub fn approval_decision( result: ApprovalReplayResult, ) -> Result<RuntimeApprovalDecision>
Errors
Errors if a store query fails.