pub enum AgentAction {
Show 18 variants
ReadFile {
paths: Vec<String>,
},
WriteFile {
path: String,
content: String,
},
EditFile {
path: String,
old_string: String,
new_string: String,
},
DeleteFile {
path: String,
},
CreateDirectory {
path: String,
},
ExecuteCommand {
command: String,
working_dir: Option<String>,
timeout: Option<u64>,
},
WebSearch {
queries: Vec<(String, usize)>,
},
WebFetch {
url: String,
},
SpawnAgent {
prompt: String,
description: String,
},
Screenshot {
mode: String,
monitor: Option<String>,
region: Option<String>,
window: Option<String>,
},
Click {
x: i32,
y: i32,
button: String,
},
TypeText {
text: String,
},
PressKey {
key: String,
},
Scroll {
direction: String,
amount: i32,
},
MouseMove {
x: i32,
y: i32,
},
ListWindows,
McpToolCall {
server_name: String,
tool_name: String,
arguments: Value,
},
ParseError {
message: String,
},
}Expand description
Represents an action that the AI wants to perform
Variants
ReadFile
Read one or more files (executor decides parallelization)
WriteFile
Write or create a file
EditFile
Make targeted edits to a file by replacing specific text
DeleteFile
Delete a file
CreateDirectory
Create a directory
ExecuteCommand
Execute a shell command
WebSearch
Web search via Ollama Cloud API (executor decides parallelization)
WebFetch
Fetch a URL’s content via Ollama Cloud API
SpawnAgent
Spawn an autonomous sub-agent with its own conversation context
Screenshot
Capture a screenshot of the screen (or a focused window/monitor/region/window)
Click
Click at screen coordinates
TypeText
Type a text string at the current cursor position
PressKey
Press a key or key combination
Scroll
Scroll in a direction
MouseMove
Move mouse cursor to coordinates
ListWindows
List all visible window titles (lightweight, no screenshot)
McpToolCall
Dynamic MCP tool call (dispatched to an MCP server at runtime)
ParseError
Placeholder for tool calls that failed to parse (never executed)
Implementations
Sourceimpl AgentAction
impl AgentAction
Sourcepub fn display_info(&self) -> (&str, String)
pub fn display_info(&self) -> (&str, String)
Extract a (type_label, target) pair for display or logging