pub struct RuntimeState {
pub provider_capabilities: ProviderCapabilitySnapshot,
pub processes: Vec<ManagedProcess>,
pub timeline: Vec<RuntimeTimelineEvent>,
}Expand description
Runtime state that is not part of the chat transcript sent to a model, but is useful for UI, slash commands, and debugging.
Fields
provider_capabilities: ProviderCapabilitySnapshotprocesses: Vec<ManagedProcess>timeline: Vec<RuntimeTimelineEvent>Implementations
Sourceimpl RuntimeState
impl RuntimeState
pub fn new(model_id: &str) -> Self
pub fn set_model(&mut self, model_id: &str)
pub fn record_signal(&mut self, signal: RuntimeSignal)
pub fn register_process(&mut self, process: ManagedProcess)