pub trait StepObserver {
// Required method
fn observe(&mut self, obs: Observation<'_>);
}Expand description
A hook on every message an Engine pumps.
Synchronous and non-blocking: observers that emit events or progress to channels (such as the subagent progress relay or broadcast streams) use non-blocking channels to ensure observer dispatch never blocks or adds latency to the reduction pump.
Required Methods
fn observe(&mut self, obs: Observation<'_>)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl StepObserver for ()
The no-op observer, for drivers that only want the reducer pumped.
impl StepObserver for ()
The no-op observer, for drivers that only want the reducer pumped.