pub fn question_modal_height(set: &PendingQuestionSet, theme: &Theme) -> u16Expand description
Total rendered height including the border, so render::mod can size the
bottom zone to fit the modal — the taller of the option list and its preview.
pub fn question_modal_height(set: &PendingQuestionSet, theme: &Theme) -> u16Total rendered height including the border, so render::mod can size the
bottom zone to fit the modal — the taller of the option list and its preview.