question_modal_height

Function question_modal_height 

pub fn question_modal_height(
    set: &PendingQuestionSet,
    theme: &Theme,
    total_width: u16,
) -> u16
Total rendered height including the border, so render::mod can size the bottom zone to fit the modal — the taller of the option list and its preview.