pub enum ApplyError {
ContextNotFound(String),
LinesNotFound(String),
}Expand description
Why applying an update hunk failed. Rendered back to the model.
Variants
ContextNotFound(String)
A @@ context anchor could not be located in the file.
LinesNotFound(String)
The old_lines span could not be located in the file.